@@ -101,7 +101,7 @@ impl Mapping {
             // only borrow `map` and `stash` and we're preserving them below.
             cx: unsafe { core::mem::transmute::<Context<'_>, Context<'static>>(cx) },
             _map: data,
-            stash: stash,
+            stash,
         })
     }
 }
@@ -123,13 +123,11 @@ impl<'data> Context<'data> {
             if cfg!(not(target_os = "aix")) {
                 let data = object.section(stash, id.name()).unwrap_or(&[]);
                 Ok(EndianSlice::new(data, Endian))
+            } else if let Some(name) = id.xcoff_name() {
+                let data = object.section(stash, name).unwrap_or(&[]);
+                Ok(EndianSlice::new(data, Endian))
             } else {
-                if let Some(name) = id.xcoff_name() {
-                    let data = object.section(stash, name).unwrap_or(&[]);
-                    Ok(EndianSlice::new(data, Endian))
-                } else {
-                    Ok(EndianSlice::new(&[], Endian))
-                }
+                Ok(EndianSlice::new(&[], Endian))
             }
         })
         .ok()?;
@@ -227,7 +225,8 @@ cfg_if::cfg_if! {
             target_os = "hurd",
             target_os = "openbsd",
             target_os = "netbsd",
-            all(target_os = "android", feature = "dl_iterate_phdr"),
+            target_os = "nto",
+            target_os = "android",
         ),
         not(target_env = "uclibc"),
     ))] {
